==> nmrium-0.53.0.tgz: package/lib/component/panels/SpectraPanel/SpectraPanelHeader.js <==
import { jsxs as _jsxs, jsx as _jsx } from "react/jsx-runtime";
import { SvgNmrSameTop, SvgNmrResetScale } from 'cheminfo-font';
import { memo, useCallback } from 'react';
import { FaCreativeCommonsSamplingPlus, FaEye, FaEyeSlash, } from 'react-icons/fa';
import { IoColorPaletteOutline } from 'react-icons/io5';
import { useChartData } from '../../context/ChartContext';
import { useDispatch } from '../../context/DispatchContext';
import { useToaster } from '../../context/ToasterContext';
import { useModal } from '../../elements/popup/Modal';
import { useActiveSpectra } from '../../hooks/useActiveSpectra';
import useSpectrum from '../../hooks/useSpectrum';
import { getSpectraByNucleus } from '../../utility/getSpectraByNucleus';
import DefaultPanelHeader from '../header/DefaultPanelHeader';
import { SpectraAutomaticPickingButton } from '../header/SpectraAutomaticPickingButton';
function getMissingProjection(spectraData, activeTab) {
    let nucleus = activeTab.split(',');
    nucleus = nucleus[0] === nucleus[1] ? [nucleus[0]] : nucleus;
    const missingNucleus = [];
    for (const n of nucleus) {
        const hasSpectra = spectraData.some((d) => d.info.nucleus === n);
        if (!hasSpectra) {
            missingNucleus.push(n);
        }
    }
    return missingNucleus;
}
function SpectraPanelHeaderInner({ data, activeSpectrum, activeSpectra, activeTab, displayerMode, onSettingClick, }) {
    const modal = useModal();
    const toaster = useToaster();
    const dispatch = useDispatch();
    const handleDelete = useCallback(() => {
        modal.showConfirmDialog({
            message: (_jsxs("span", { children: ["You are about to delete", _jsxs("span", { style: { color: 'black' }, children: [" ", activeSpectra?.length, " "] }), "spectra, Are you sure?"] })),
            buttons: [
                {
                    text: 'Yes',
                    handler: () => {
                        dispatch({ type: 'DELETE_SPECTRA', payload: {} });
                    },
                },
                { text: 'No' },
            ],
        });
    }, [activeSpectra?.length, dispatch, modal]);
    function showAllSpectraHandler() {
        dispatch({
            type: 'CHANGE_SPECTRA_VISIBILITY_BY_NUCLEUS',
            payload: { nucleus: activeTab, flag: true },
        });
    }
    function hideAllSpectraHandler() {
        dispatch({
            type: 'CHANGE_SPECTRA_VISIBILITY_BY_NUCLEUS',
            payload: { nucleus: activeTab, flag: false },
        });
    }
    function addMissingProjectionHandler() {
        const missingNucleus = getMissingProjection(data, activeTab);
        if (missingNucleus.length > 0) {
            dispatch({
                type: 'ADD_MISSING_PROJECTION',
                payload: { nucleus: missingNucleus },
            });
        }
        else {
            toaster.show({ message: 'Nothing to calculate', intent: 'danger' });
        }
    }
    function setSameTopHandler() {
        dispatch({ type: 'SET_SPECTRA_SAME_TOP' });
    }
    function resetScaleHandler() {
        dispatch({ type: 'RESET_SPECTRA_SCALE' });
    }
    function reColorSpectraHandler() {
        dispatch({
            type: 'RECOLOR_SPECTRA_COLOR',
            payload: {},
        });
    }
    const hasActiveSpectra = activeSpectra && activeSpectra?.length > 0;
    const spectraLengthPerTab = getSpectraByNucleus(activeTab, data)?.length;
    let leftButtons = [
        {
            disabled: !hasActiveSpectra,
            icon: _jsx(FaEyeSlash, {}),
            title: 'Hide selected spectra',
            onClick: hideAllSpectraHandler,
        },
        {
            disabled: !hasActiveSpectra,
            icon: _jsx(FaEye, {}),
            title: 'Show selected spectra',
            onClick: showAllSpectraHandler,
        },
    ];
    if (displayerMode === '2D' && activeSpectrum?.info.isFt) {
        leftButtons.push({
            icon: _jsx(FaCreativeCommonsSamplingPlus, {}),
            title: 'Add missing projection',
            onClick: addMissingProjectionHandler,
        });
    }
    if (displayerMode === '1D' && spectraLengthPerTab > 1) {
        leftButtons.push({
            icon: _jsx(SvgNmrResetScale, {}),
            title: 'Reset scale',
            onClick: resetScaleHandler,
        }, {
            icon: _jsx(SvgNmrSameTop, {}),
            title: 'Same top',
            onClick: setSameTopHandler,
        });
    }
    leftButtons = leftButtons.concat([
        {
            component: _jsx(SpectraAutomaticPickingButton, {}),
        },
        {
            icon: _jsx(IoColorPaletteOutline, {}),
            title: 'Recolor spectra',
            onClick: reColorSpectraHandler,
        },
    ]);
    return (_jsx(DefaultPanelHeader, { onDelete: handleDelete, total: data?.length, counter: spectraLengthPerTab, deleteToolTip: "Delete selected spectra", disableDelete: !hasActiveSpectra, onSettingClick: onSettingClick, leftButtons: leftButtons }));
}
const MemoizedSpectraPanelHeader = memo(SpectraPanelHeaderInner);
export default function SpectraTabs({ onSettingClick, }) {
    const { data, view: { spectra: { activeTab }, }, displayerMode, } = useChartData();
    const spectrum = useSpectrum();
    const activeSpectra = useActiveSpectra();
    return (_jsx(MemoizedSpectraPanelHeader, { data,
        activeSpectrum: spectrum,
        activeSpectra,
        activeTab,
        displayerMode,
        onSettingClick }));
}

==> nmrium-0.55.0.tgz: package/lib/component/panels/SpectraPanel/SpectraPanelHeader.js <==
import { jsxs as _jsxs, jsx as _jsx } from "react/jsx-runtime";
import { SvgNmrSameTop, SvgNmrResetScale } from 'cheminfo-font';
import { memo, useCallback } from 'react';
import { FaCreativeCommonsSamplingPlus, FaEye, FaEyeSlash, } from 'react-icons/fa';
import { IoColorPaletteOutline } from 'react-icons/io5';
import { MdFormatColorFill } from 'react-icons/md';
import { useChartData } from '../../context/ChartContext';
import { useDispatch } from '../../context/DispatchContext';
import { usePreferences } from '../../context/PreferencesContext';
import { useToaster } from '../../context/ToasterContext';
import { useModal } from '../../elements/popup/Modal';
import { useActiveSpectra } from '../../hooks/useActiveSpectra';
import useSpectrum from '../../hooks/useSpectrum';
import { getSpectraByNucleus } from '../../utility/getSpectraByNucleus';
import DefaultPanelHeader from '../header/DefaultPanelHeader';
import { SpectraAutomaticPickingButton } from '../header/SpectraAutomaticPickingButton';
function getMissingProjection(spectraData, activeTab) {
    let nucleus = activeTab.split(',');
    nucleus = nucleus[0] === nucleus[1] ? [nucleus[0]] : nucleus;
    const missingNucleus = [];
    for (const n of nucleus) {
        const hasSpectra = spectraData.some((d) => d.info.nucleus === n);
        if (!hasSpectra) {
            missingNucleus.push(n);
        }
    }
    return missingNucleus;
}
function SpectraPanelHeaderInner({ data, activeSpectrum, activeSpectra, activeTab, displayerMode, onSettingClick, }) {
    const modal = useModal();
    const toaster = useToaster();
    const dispatch = useDispatch();
    const { current: { spectraColors }, } = usePreferences();
    const handleDelete = useCallback(() => {
        modal.showConfirmDialog({
            message: (_jsxs("span", { children: ["You are about to delete", _jsxs("span", { style: { color: 'black' }, children: [" ", activeSpectra?.length, " "] }), "spectra, Are you sure?"] })),
            buttons: [
                {
                    text: 'Yes',
                    handler: () => {
                        dispatch({ type: 'DELETE_SPECTRA', payload: {} });
                    },
                },
                { text: 'No' },
            ],
        });
    }, [activeSpectra?.length, dispatch, modal]);
    function showAllSpectraHandler() {
        dispatch({
            type: 'CHANGE_SPECTRA_VISIBILITY_BY_NUCLEUS',
            payload: { nucleus: activeTab, flag: true },
        });
    }
    function hideAllSpectraHandler() {
        dispatch({
            type: 'CHANGE_SPECTRA_VISIBILITY_BY_NUCLEUS',
            payload: { nucleus: activeTab, flag: false },
        });
    }
    function addMissingProjectionHandler() {
        const missingNucleus = getMissingProjection(data, activeTab);
        if (missingNucleus.length > 0) {
            dispatch({
                type: 'ADD_MISSING_PROJECTION',
                payload: { nucleus: missingNucleus },
            });
        }
        else {
            toaster.show({ message: 'Nothing to calculate', intent: 'danger' });
        }
    }
    function setSameTopHandler() {
        dispatch({ type: 'SET_SPECTRA_SAME_TOP' });
    }
    function resetScaleHandler() {
        dispatch({ type: 'RESET_SPECTRA_SCALE' });
    }
    function defaultReColorSpectraHandler() {
        dispatch({
            type: 'RECOLOR_SPECTRA_COLOR',
            payload: { customColors: spectraColors },
        });
    }
    function distinctReColorSpectraHandler() {
        dispatch({
            type: 'RECOLOR_SPECTRA_COLOR',
            payload: {},
        });
    }
    const hasActiveSpectra = activeSpectra && activeSpectra?.length > 0;
    const spectraLengthPerTab = getSpectraByNucleus(activeTab, data)?.length;
    let leftButtons = [
        {
            disabled: !hasActiveSpectra,
            icon: _jsx(FaEyeSlash, {}),
            tooltip: 'Hide selected spectra',
            onClick: hideAllSpectraHandler,
        },
        {
            disabled: !hasActiveSpectra,
            icon: _jsx(FaEye, {}),
            tooltip: 'Show selected spectra',
            onClick: showAllSpectraHandler,
        },
    ];
    if (displayerMode === '2D' && activeSpectrum?.info.isFt) {
        leftButtons.push({
            icon: _jsx(FaCreativeCommonsSamplingPlus, {}),
            tooltip: 'Add missing projection',
            onClick: addMissingProjectionHandler,
        });
    }
    if (displayerMode === '1D' && spectraLengthPerTab > 1) {
        leftButtons.push({
            icon: _jsx(SvgNmrResetScale, {}),
            tooltip: 'Reset scale',
            onClick: resetScaleHandler,
        }, {
            icon: _jsx(SvgNmrSameTop, {}),
            tooltip: 'Same top',
            onClick: setSameTopHandler,
        });
    }
    leftButtons = leftButtons.concat([
        {
            component: _jsx(SpectraAutomaticPickingButton, {}),
        },
        {
            icon: _jsx(IoColorPaletteOutline, {}),
            tooltip: 'Default spectra recoloring',
            onClick: defaultReColorSpectraHandler,
        },
        {
            icon: _jsx(MdFormatColorFill, {}),
            tooltip: 'Distinct spectra recoloring',
            onClick: distinctReColorSpectraHandler,
        },
    ]);
    return (_jsx(DefaultPanelHeader, { onDelete: handleDelete, total: data?.length, counter: spectraLengthPerTab, deleteToolTip: "Delete selected spectra", disableDelete: !hasActiveSpectra, onSettingClick: onSettingClick, leftButtons: leftButtons }));
}
const MemoizedSpectraPanelHeader = memo(SpectraPanelHeaderInner);
export default function SpectraTabs({ onSettingClick, }) {
    const { data, view: { spectra: { activeTab }, }, displayerMode, } = useChartData();
    const spectrum = useSpectrum();
    const activeSpectra = useActiveSpectra();
    return (_jsx(MemoizedSpectraPanelHeader, { data,
        activeSpectrum: spectrum,
        activeSpectra,
        activeTab,
        displayerMode,
        onSettingClick }));
}
